# Choices
CHOICE_STATUS = (
		('0', 'Inactive'),
		('1', 'Active')
	)


# default column names

COLUMN_NAME_ACTIVE = 'active'
COLUMN_NAME_DELETED = 'deleted'

COLUMN_NAME_DELETED_BY = 'deleted_by'
COLUMN_NAME_DELETED_AT = 'deleted_at'

COLUMN_NAME_CREATED_BY = 'created_by'
COLUMN_NAME_CREATED_AT = 'created_at'

COLUMN_NAME_UPDATED_BY = 'updated_by'
COLUMN_NAME_UPDATED_AT = 'updated_at'


