
CRUD_URL_PK = '/<str:pk>'
CREATE_ACTION = 'create'
RETRIEVE_ACTION = 'retrieve'
UPDATE_ACTION = 'update'
DELETE_ACTION = 'delete'
LIST_ACTION = 'list'
LIST_URL = '/list'

ALL_ACTIONS = [
	CREATE_ACTION, RETRIEVE_ACTION,
	DELETE_ACTION, UPDATE_ACTION, LIST_ACTION
]
